@@ -43,14 +43,14 @@ head(dat1)
 ## ----sdForEachRow, echo=TRUE--------------------------------------------------
 head(rowSds(dat1))
 system.time(sd1 <- rowSds(dat1))
-system.time(sd2 <- apply(dat1,1,sd))
+system.time(sd2 <- apply(dat1, 1, sd))
 
 ## ----usingApply, echo=TRUE----------------------------------------------------
-table(round(sd1,13)==round(sd2,13))
+table(round(sd1, 13)==round(sd2, 13))
 
 ## ----calculateRowCV, echo=TRUE------------------------------------------------
 system.time(cv1 <- rowCVs(dat1))
-system.time(cv2 <- apply(dat1,1,sd)/rowMeans(dat1))
+system.time(cv2 <- apply(dat1, 1, sd) / rowMeans(dat1))
 # typically the calculation using rowCVs is much faster
 head(cv1)
 # results from the 'conventional' way
@@ -97,7 +97,7 @@ str(naOmit(aA))
 str(na.omit(aA))
 
 ## ----minDiff, echo=TRUE-------------------------------------------------------
-set.seed(2017); aa <- 10*c(0.1 +round(runif(20),2), 0.53, 0.53)
+set.seed(2017); aa <- 10 *c(0.1 +round(runif(20),2), 0.53, 0.53)
 head(aa)
 
 minDiff(aa,ppm=FALSE)
@@ -123,13 +123,34 @@ append(li1, li2)
 appendNR(li1, li2)
 
 ## ----lrbind, echo=TRUE--------------------------------------------------------
-dat2 <- matrix(11:34, ncol=3, dimnames=list(letters[1:8],colnames=LETTERS[1:3]))
+dat2 <- matrix(11:34, ncol=3, dimnames=list(letters[1:8], colnames=LETTERS[1:3]))
 lst2 <- by(dat2, rep(1:3,c(3,2,3)), as.matrix)
 lst2
 
 # join list-elements (back) into single matrix
 lrbind(lst2)
 
+## ----mergeMatrixList, echo=TRUE-----------------------------------------------
+mat1 <- matrix(11:18, ncol=2, dimnames=list(letters[3:6],LETTERS[1:2]))
+mat2 <- matrix(21:28, ncol=2, dimnames=list(letters[2:5],LETTERS[3:4]))
+mat3 <- matrix(31:38, ncol=2, dimnames=list(letters[c(1,3:4,3)],LETTERS[4:5]))
+#
+mergeMatrixList(list(mat1, mat2), useColumn="all")
+
+# with custom names for the individual matrices
+mergeMatrixList(list(m1=mat1, m2=mat2, mat3), mode="union", useColumn=2)
+
+## ----mergeMatrices, echo=TRUE-------------------------------------------------
+mergeMatrices(mat1, mat2)
+
+mergeMatrices(mat1, mat2, mat3, mode="union", useColumn=2)
+
+## custom names for matrix-origin
+mergeMatrices(m1=mat1, m2=mat2, mat3, mode="union", useColumn=2)
+
+## flexible/custom selection of columns
+mergeMatrices(m1=mat1, m2=mat2, mat3, mode="union", useColumn=list(1,1:2,2))
+
 ## ----fuseCommonListElem, echo=TRUE--------------------------------------------
 val1 <- 10 +1:26
 names(val1) <- letters
@@ -142,14 +163,14 @@ names(lst1)
 fuseCommonListElem(lst1)
 
 ## ----listBatchReplace1, echo=TRUE---------------------------------------------
-lst1 <- list(m1=matrix(11:18,ncol=2), m2=matrix(21:30,ncol=2), indR=31:34,
-  m3=matrix(c(21:23,NA,25:27,NA),ncol=2))
+lst1 <- list(m1=matrix(11:18, ncol=2), m2=matrix(21:30, ncol=2), indR=31:34,
+  m3=matrix(c(21:23,NA,25:27,NA), ncol=2))
 filterLiColDeList(lst1, useLines=2:3)
 filterLiColDeList(lst1, useLines="allNA", ref=3)
 
 ## ----replInList1, echo=TRUE---------------------------------------------------
-(lst1 <- list(aa=1:4, bb=c("abc","efg","abhh","effge") ,cc=c("abdc","efg","efgh")))
-listBatchReplace(lst1,search="efg",repl="EFG",silent=FALSE)
+(lst1 <- list(aa=1:4, bb=c("abc","efg","abhh","effge"), cc=c("abdc","efg","efgh")))
+listBatchReplace(lst1, search="efg", repl="EFG", silent=FALSE)
 
 ## ----listGroupsByNames, echo=TRUE---------------------------------------------
 ser1 <- 1:7; names(ser1) <- c("AA","BB","AA.1","CC","AA.b","BB.e","A")
@@ -188,7 +209,7 @@ arrayCV(arr1, byDim=2)
 cutArrayInCluLike(arr1, cluOrg=c(2,1,2,1))
 
 ## ----filt3dimArr, echo=TRUE---------------------------------------------------
-filt3dimArr(arr1,displCrit=c("col1","col2"), filtCrit="col2", filtVal=7, filtTy=">")
+filt3dimArr(arr1, displCrit=c("col1","col2"), filtCrit="col2", filtVal=7, filtTy=">")
 
 ## ----repeated1, echo=TRUE-----------------------------------------------------
 ## some text toy data
@@ -225,6 +246,16 @@ unique(aa)                                    # names are lost
 nonAmbiguousNum(aa)
 nonAmbiguousNum(aa, uniq=FALSE, asLi=TRUE)    # separate in list unique and repeated 
 
+## ----sortByNRepeated, echo=TRUE-----------------------------------------------
+cities <- c("Bangkok","London","Paris", "Singapore","New York City", "Istambul","Delhi","Rome","Dubai")
+sortByNRepeated(x=cities[c(1:4)], y=cities[c(2:3,5:8)])
+
+## or (unlimited) multiple inputs via list
+choices1 <- list(Mary=cities[c(1:4)], Olivia=cities[c(2:3,5:8)], Paul=cities[c(5:3,9,5)])    # Note : Paul cited NYC twice !
+table(unlist(choices1))
+sortByNRepeated(choices1)
+sortByNRepeated(choices1, filterIntraRep=FALSE)  # without correcting multiple citation of NYC by Paul
+
 ## ----cbindNR, echo=TRUE-------------------------------------------------------
 ## First we'll make soe toy data :
 (ma1 <- matrix(1:6, ncol=3, dimnames=list(1:2,LETTERS[3:1])))
@@ -234,7 +265,7 @@ nonAmbiguousNum(aa, uniq=FALSE, asLi=TRUE)    # separate in list unique and repe
 cbindNR(ma1, ma2, summarizeAs="mean")       # average of both columns 'C'
 
 ## ----firstLineOfDat, echo=TRUE------------------------------------------------
-(mat1 <- matrix(c(1:6,rep(1:3,1:3)), ncol=2, dimnames=list(letters[1:6],LETTERS[1:2])))
+(mat1 <- matrix(c(1:6, rep(1:3,1:3)), ncol=2, dimnames=list(letters[1:6],LETTERS[1:2])))
 
 ## ----firstLineOfDat2, echo=TRUE-----------------------------------------------
 firstLineOfDat(mat1, refCol=2)
@@ -283,6 +314,13 @@ head(get1stOfRepeatedByCol(mat3, sortB="B", sortS="B"))
 lst2 <- list(aa_1x=matrix(1:12, nrow=4, byrow=TRUE), ab_2x=matrix(24:13, nrow=4, byrow=TRUE))
 combineReplFromListToMatr(lst2)
 
+## ----combineRedundLinesInListAcRef, echo=TRUE---------------------------------
+x1 <- list(quant=matrix(11:34, ncol=3, dimnames=list(letters[8:1], LETTERS[11:13])), 
+  annot=matrix(paste0(LETTERS[c(1:4,6,3:5)],LETTERS[c(1:4,6,3:5)]), ncol=1, 
+  dimnames=list(paste(letters[1:8]),"xx")) )
+combineRedundLinesInListAcRef(x1, c("annot","quant"), refColNa="xx")
+combineRedundLinesInListAcRef(lst=x1, listNa=c(quant="quant",ref="annot"), refColNa="xx")
+
 ## ----nonRedundLines, echo=TRUE------------------------------------------------
 mat4 <- matrix(rep(c(1,1:3,3,1),2), ncol=2, dimnames=list(letters[1:6],LETTERS[1:2]))
 nonRedundLines(mat4)
@@ -296,8 +334,8 @@ filtSizeUniq(list(A="a", B=c("b","bb","c"), D=c("dd","d","ddd","c")), ref=c(lett
   "dd","dd","bb","ddd"), filtUn=TRUE, minSi=NULL)   
 
 ## ----makeNRedMatr, echo=TRUE--------------------------------------------------
-t3 <- data.frame(ref=rep(11:15,3),tx=letters[1:15],
-  matrix(round(runif(30,-3,2),1),nc=2), stringsAsFactors=FALSE)
+t3 <- data.frame(ref=rep(11:15,3), tx=letters[1:15],
+  matrix(round(runif(30,-3,2),1), nc=2), stringsAsFactors=FALSE)
   
 # First we split the data.frame in list  
 by(t3,t3[,1],function(x) x)
@@ -313,12 +351,12 @@ combineRedBasedOnCol(rbind(matr[1,],matr), colN="xB")
 
 ## ----convMatr2df, echo=TRUE---------------------------------------------------
 x <- 1
-dat1 <- matrix(1:10,ncol=2)
+dat1 <- matrix(1:10, ncol=2)
 rownames(dat1) <- letters[c(1:3,2,5)]
 ## as.data.frame(dat1)  ...  would result in an error
 convMatr2df(dat1)
 convMatr2df(data.frame(a=as.character((1:3)/2), b=LETTERS[1:3], c=1:3))
-tmp <- data.frame(a=as.character((1:3)/2), b=LETTERS[1:3],c=1:3, stringsAsFactors=FALSE)
+tmp <- data.frame(a=as.character((1:3)/2), b=LETTERS[1:3], c=1:3, stringsAsFactors=FALSE)
 convMatr2df(tmp)
 tmp <- data.frame(a=as.character((1:3)/2), b=1:3, stringsAsFactors=FALSE)
 convMatr2df(tmp) 
@@ -328,11 +366,11 @@ set.seed(2013)
 datT2 <- matrix(round(rnorm(200)+3,1), ncol=2, dimnames=list(paste("li",1:100,sep=""),
   letters[23:24]))
 # (mimick) some short and longer names for each line
-inf2 <- cbind(sh=paste(rep(letters[1:4],each=26),rep(letters,4),1:(26*4),sep=""),
+inf2 <- cbind(sh=paste(rep(letters[1:4],each=26), rep(letters,4),1:(26*4),sep=""),
   lo=paste(rep(LETTERS[1:4],each=26), rep(LETTERS,4), 1:(26*4), ",", 
   rep(letters[sample.int(26)],4), rep(letters[sample.int(26)],4), sep=""))[1:100,] 
 ## We'll use this to test :  
-head(datT2,n=10)
+head(datT2, n=10)
 ## let's assign to each pair of x & y values a 'cluster' (column _clu_, the column _combInf_ tells us which lines/indexes are in this cluster)
 head(combineOverlapInfo(datT2, disThr=0.03), n=10)
 ## it is also possible to rather display names (eg gene or protein-names) instead of index values
@@ -345,11 +383,11 @@ names(dat) <- letters[c(6:3,2:4,8,3)]
 ## Thus, the values can be binned by their (non-unique) names and a representative values calculated.
 
 ## Let's make a 'datUniq' with the mean of each group of values :
-datUniq <- round(tapply(dat, names(dat),mean),1)
+datUniq <- round(tapply(dat, names(dat), mean),1)
 ## now we propagate the mean values to the full vector 
 getValuesByUnique(dat, datUniq)
 cbind(ini=dat,firstOfRep=getValuesByUnique(dat, datUniq),
-  indexUniq=getValuesByUnique(dat, datUniq,asIn=TRUE))
+  indexUniq=getValuesByUnique(dat, datUniq, asIn=TRUE))
 
 ## ----combineByEitherFactor, echo=TRUE-----------------------------------------
 nn <- rep(c("a","e","b","c","d","g","f"),c(3,1,2,2,1,2,1))
@@ -357,19 +395,19 @@ qq <- rep(c("m","n","p","o","q"),c(2,1,1,4,4))
 nq <- cbind(nn,qq)[c(4,2,9,11,6,10,7,3,5,1,12,8),]
 ## Here we consider 2 columns 'nn' and 'qq' whe trying to regroup common values
 ##  (eg value 'a' from column 'nn' and value 'o' from 'qq') 
-combineByEitherFactor(nq,1,2,nBy=FALSE)
+combineByEitherFactor(nq, 1, 2, nBy=FALSE)
 
 ## ----combineByEitherFactor2, echo=TRUE----------------------------------------
 ## the same, but including n by group/cluster
-combineByEitherFactor(nq,1,2,nBy=TRUE)
+combineByEitherFactor(nq, 1, 2, nBy=TRUE)
 ## Not running further iterations works faster, but you may not reach 'convergence' immediately
-combineByEitherFactor(nq,1,2,nBy=FALSE)
+combineByEitherFactor(nq,1, 2, nBy=FALSE)
 
 ## ----combineByEitherFactor3, echo=TRUE----------------------------------------
 ##  another example
-mm <- rep(c("a","b","c","d","e"),c(3,4,2,3,1))
-pp <- rep(c("m","n","o","p","q"),c(2,2,2,2,5))
-combineByEitherFactor(cbind(mm,pp),1,2, con=FALSE, nBy=TRUE)
+mm <- rep(c("a","b","c","d","e"), c(3,4,2,3,1))
+pp <- rep(c("m","n","o","p","q"), c(2,2,2,2,5))
+combineByEitherFactor(cbind(mm,pp), 1, 2, con=FALSE, nBy=TRUE)
 
 ## ----multiCharReplace1, echo=TRUE---------------------------------------------
 # replace character content
@@ -420,9 +458,9 @@ replicateStructure(bb, method="combAll")
 replicateStructure(bb, method="combNonOrth")
 
 ## ----checkSimValueInSer, echo=TRUE--------------------------------------------
-va1 <- c(4:7,7,7,7,7,8:10) +(1:11)/28600
-checkSimValueInSer(va1)
-cbind(va=va1, simil=checkSimValueInSer(va1))
+va1 <- c(4:7,7,7,7,7,8:10) + (1:11)/28600
+checkSimValueInSer(va1, ppm=5)
+data.frame(va=sort(va1), simil=checkSimValueInSer(va1))
 
 ## ----findCloseMatch1, echo=TRUE-----------------------------------------------
 aA <- c(11:17); bB <- c(12.001,13.999); cC <- c(16.2,8,9,12.5,15.9,13.5,15.7,14.1,5)
@@ -434,29 +472,29 @@ aA <- c(11:17); bB <- c(12.001,13.999); cC <- c(16.2,8,9,12.5,15.9,13.5,15.7,14.
 (maAa <- closeMatchMatrix(cloMa, aA, cC, lim=TRUE))  #
 
 ## ----closeMatchMatrix2, echo=TRUE---------------------------------------------
-(maAa <- closeMatchMatrix(cloMa,aA, cC, lim=FALSE,origN=TRUE))  #
-(maAa <- closeMatchMatrix(cloMa, cbind(valA=81:87,aA), cbind(valC=91:99,cC), colM=2,
-  colP=2,lim=FALSE))
+(maAa <- closeMatchMatrix(cloMa, aA, cC, lim=FALSE,origN=TRUE))  #
+(maAa <- closeMatchMatrix(cloMa, cbind(valA=81:87, aA), cbind(valC=91:99, cC), colM=2,
+  colP=2, lim=FALSE))
 (maAa <- closeMatchMatrix(cloMa, cbind(aA,valA=81:87), cC, lim=FALSE, deb=TRUE))  #
-a2 <- aA; names(a2) <- letters[1:length(a2)];  c2 <- cC; names(c2) <- letters[10+1:length(c2)]
+a2 <- aA; names(a2) <- letters[1:length(a2)];  c2 <- cC; names(c2) <- letters[10 +1:length(c2)]
 (cloM2 <- findCloseMatch(x=a2, y=c2, com="diff", lim=0.5, sor=FALSE)) 
-(maA2 <- closeMatchMatrix(cloM2, predM=cbind(valA=81:87,a2), 
-  measM=cbind(valC=91:99,c2), colM=2, colP=2, lim=FALSE, asData=TRUE)) 
-(maA2 <- closeMatchMatrix(cloM2, cbind(id=names(a2),valA=81:87,a2), cbind(id=names(c2),
+(maA2 <- closeMatchMatrix(cloM2, predM=cbind(valA=81:87, a2),
+  measM=cbind(valC=91:99, c2), colM=2, colP=2, lim=FALSE, asData=TRUE))
+(maA2 <- closeMatchMatrix(cloM2, cbind(id=names(a2), valA=81:87,a2), cbind(id=names(c2),
   valC=91:99,c2), colM=3, colP=3, lim=FALSE, deb=FALSE)) 
 
 ## ----findSimilFrom2sets, echo=TRUE--------------------------------------------
 aA <- c(11:17); bB <- c(12.001,13.999); cC <- c(16.2,8,9,12.5,12.6,15.9,14.1)
 aZ <-  matrix(c(aA,aA+20), ncol=2, dimnames=list(letters[1:length(aA)],c("aaA","aZ")))
 cZ <-  matrix(c(cC,cC+20), ncol=2, dimnames=list(letters[1:length(cC)],c("ccC","cZ")))
-findCloseMatch(cC,aA,com="diff",lim=0.5,sor=FALSE)
-findSimilFrom2sets(aA,cC)
-findSimilFrom2sets(cC,aA)
-findSimilFrom2sets(aA,cC,best=FALSE)
-findSimilFrom2sets(aA,cC,comp="ppm",lim=5e4,deb=TRUE)
-findSimilFrom2sets(aA,cC,comp="ppm",lim=9e4,bestO=FALSE)
+findCloseMatch(cC, aA, com="diff", lim=0.5, sor=FALSE)
+findSimilFrom2sets(aA, cC)
+findSimilFrom2sets(cC, aA)
+findSimilFrom2sets(aA, cC, best=FALSE)
+findSimilFrom2sets(aA, cC, comp="ppm", lim=5e4, deb=TRUE)
+findSimilFrom2sets(aA, cC, comp="ppm", lim=9e4, bestO=FALSE)
 # below: find fewer 'best matches' since search window larger (ie more good hits compete !)
-findSimilFrom2sets(aA,cC,comp="ppm",lim=9e4,bestO=TRUE)      
+findSimilFrom2sets(aA, cC, comp="ppm", lim=9e4, bestO=TRUE)
 
 ## ----fusePairs, echo=TRUE-----------------------------------------------------
 (daPa <- matrix(c(1:5,8,2:6,9), ncol=2))
@@ -494,11 +532,106 @@ stableMode(dat, method="mode")
 stableMode(dat, method="allModes")
 
 ## ----trimRedundText1, echo=TRUE-----------------------------------------------
-x <- c("abcd","abcde","abcdefg","abcdE",NA,"abcdEF")
-trimRedundText(x)
+txt1 <- c("abcd","abcde","abcdefg","abcdE",NA,"abcdEF")
+trimRedundText(txt1)
+
+## ----keepCommonText1, echo=TRUE-----------------------------------------------
+txt1 <- c("abcd","abcde","abcdefg","abcdE",NA,"abcdEF")
+trimRedundText(txt1, side="left")         # remove redundant 
+keepCommonText(txt1, side="terminal")     # keep redundant
+keepCommonText(txt1, side="center")       # computationally easier   
+
+## ----keepCommonText2, echo=TRUE-----------------------------------------------
+txt2 <- c("abcd_abc_kjh", "bcd_abc123", "cd_abc_po")
+keepCommonText(txt2, side="center")       
+
+## ----rmEnumeratorName1, echo=TRUE---------------------------------------------
+xx <- c("hg_Re1","hjRe2_Re2","hk-Re3_Re33")
+rmEnumeratorName(xx)
+rmEnumeratorName(xx, newSep="--")
+rmEnumeratorName(xx, incl="anyCase")
+
+## ----rmEnumeratorName2, echo=TRUE---------------------------------------------
+xy <- cbind(a=11:13, b=c("11#11","2_No2","333_samp333"), c=xx)
+rmEnumeratorName(xy)
+rmEnumeratorName(xy,incl=c("anyCase","trim2","rmEnumL"))
+
+## ----rmEnumeratorName3, echo=TRUE---------------------------------------------
+xz <- cbind(a=11:13, b=c("23#11","4#2","567#333"), c=xx)
+apply(xz, 2, rmEnumeratorName, sepEnum=c("","_"), newSep="_", silent=TRUE)
+
+## ----unifyEnumerator1, echo=TRUE----------------------------------------------
+unifyEnumerator(c("ab-1","ab-2","c-3"))
+unifyEnumerator(c("ab-R1","ab-R2","c-R3"))
+unifyEnumerator(c("ab-1","c3-2","dR3"), stringentMatch=FALSE)
+
+## ----adjustUnitPrefix1, echo=TRUE---------------------------------------------
+adjustUnitPrefix(c("10.psec","2 fsec"), unit="sec")
+
+## ----adjustUnitPrefix2, echo=TRUE---------------------------------------------
+adjustUnitPrefix(c("10.psec abc","2 fsec etc"), unit="sec")
+
+## ----mergeVectors1, echo=TRUE-------------------------------------------------
+x1 <- c(a=1, b=11, c=21)
+x2 <- c(b=12, c=22, a=2)
+x3 <- c(a=3, d=43)
+mergeVectors(vect1=x1, vect2=x2, vect3=x3)
+
+## ----mergeVectors2, echo=TRUE-------------------------------------------------
+mergeVectors(vect1=x1, vect2=x2, vect3=x3, inclInfo=TRUE)   # return list with additional info
+
+## ----mergeVectors3, echo=TRUE-------------------------------------------------
+x4 <- 41:44            # no names - not conform for merging and will be ignored
+mergeVectors(x1, x2, x3, x4)
+
+## ----matchMatrixLinesToRef1, echo=TRUE----------------------------------------
+## Note : columns b and e allow non-ambigous match, not all elements of e are present in a
+mat0 <- cbind(a=c("mvvk","axxd","bxxd","vv"),b=c("iwwy","iyyu","kvvh","gxx"), c=rep(9,4),
+  d=c("hgf","hgf","vxc","nvnn"), e=c("_vv_","_ww_","_xx_","_yy_"))
+matchMatrixLinesToRef(mat0[,1:4], ref=mat0[,5])
+matchMatrixLinesToRef(mat0[,1:4], ref=mat0[1:3,5], inclInfo=TRUE)
+
+matchMatrixLinesToRef(mat0[,-2], ref=mat0[,2], inclInfo=TRUE)   # needs 'reverse grep'
+
+## ----orderMatrToRef1, echo=TRUE-----------------------------------------------
+mat1 <- matrix(paste0("__",letters[rep(c(1,1,2,2,3),3) +rep(0:2,each=5)], rep(1:5)), ncol=3)
+orderMatrToRef(mat1, paste0(letters[c(3,4,5,3,4)],c(1,3,5,2,4)))
+
+mat2 <- matrix(paste0("__",letters[rep(c(1,1,2,2,3),3) +rep(0:2,each=5)], c(rep(1:5,2),1,1,3:5 )), ncol=3)
+orderMatrToRef(mat2, paste0(letters[c(3,4,5,3,4)],c(1,3,5,1,4)))
+
+mat3 <- matrix(paste0(letters[rep(c(1,1,2,2,3),3) +rep(0:2,each=5)], c(rep(1:5,2),1,1,3,3,5 )), ncol=3)
+orderMatrToRef(mat3, paste0("__",letters[c(3,4,5,3,4)],c(1,3,5,1,3)))
+
+## ----concatMatch1, echo=TRUE--------------------------------------------------
+## simple example without concatenations or text-extensions
+x0 <- c("ZZ","YY","AA","BB","DD","CC","D")
+tab0 <- c("AA","BB,E","CC","FF,U")
+match(x0, tab0)
+concatMatch(x0, tab0)         # same result as match(), but with names
+
+## now let's construct somthing similar but with concatenations and text-extensions
+x1 <- c("ZZ","YY","AA","BB-2","DD","CCdef","Dxy")            # modif of single ID (no concat)
+tab1 <- c("AA","WW,Vde,BB-5,E","CCab","FF,Uef")
+match(x1, tab1)                   # match finds only the 'simplest' case (ie "AA")
+concatMatch(x1, tab1)             # finds all hits as in example above
+
+x2 <- c("ZZ,Z","YY,Y","AA,Z,Y","BB-2","DD","X,CCdef","Dxy")  # conatenated in 'x'
+tab2 <- c("AA","WW,Vde,BB-5,E","CCab,WW","FF,UU")
+concatMatch(x2, tab2)               # concatenation in both 'x' and 'table'
+
+## ----checkStrictOrder1, echo=TRUE---------------------------------------------
+set.seed(2005); mat1 <- rbind(matrix(round(runif(40),1),nc=4), rep(1,4))
+head(mat1)
+checkStrictOrder(mat1); mat1[which(checkStrictOrder(mat1)[,2]==0),]
+
+## ----checkGrpOrder1, echo=TRUE------------------------------------------------
+head(mat1)
+checkGrpOrder(mat1)
+checkGrpOrder(mat1, revRank=FALSE)    # only constant 'up' tested
 
 ## ----linModelSelect1, echo=TRUE-----------------------------------------------
-li1 <- rep(c(4,3,3:6),each=3) + round(runif(18)/5,2)
+li1 <- rep(c(4,3,3:6), each=3) + round(runif(18)/5,2)
 names(li1) <- paste0(rep(letters[1:5], each=3), rep(1:3,6))
 li2 <- rep(c(6,3:7), each=3) + round(runif(18)/5, 2)
 dat2 <- rbind(P1=li1, P2=li2)
@@ -532,12 +665,25 @@ if(wrGraphOK) wrGraph::plotW2Leg(x1.lmSum, useCol=c("Pr(>|t|)","Estimate","medQu
 set.seed(2014); ra1 <- c(rnorm(9,2,1), runif(8,1,2))
 
 ## ----ratioAllComb1, echo=TRUE-------------------------------------------------
-median(ra1[1:9])/median(ra1[10:17])
+median(ra1[1:9]) / median(ra1[10:17])
 
 ## ----ratioAllComb2, echo=TRUE-------------------------------------------------
 summary( ratioAllComb(ra1[1:9], ra1[10:17]))
 boxplot(list(norm=ra1[1:9], unif=ra1[10:17], rat=ratioAllComb(ra1[1:9],ra1[10:17])))
 
+## ----combineAsN1, echo=TRUE---------------------------------------------------
+tm1 <- list(a1=LETTERS[1:7], a2=LETTERS[3:9], a3=LETTERS[6:10], a4=LETTERS[8:12])
+combineAsN(tm1, nCombin=3, lev=gl(1,4))[,1,]
+
+## ----combineAsN2, echo=TRUE---------------------------------------------------
+## different levels/groups in list-elements
+tm4 <- list(a1=LETTERS[1:15], a2=LETTERS[3:16], a3=LETTERS[6:17], a4=LETTERS[8:19],
+  b1=LETTERS[5:19], b2=LETTERS[7:20], b3=LETTERS[11:24], b4=LETTERS[13:25], c1=LETTERS[17:26],
+  d1=LETTERS[4:12], d2=LETTERS[5:11], d3=LETTERS[6:12], e1=LETTERS[7:10])
+te4 <- combineAsN(tm4, nCombin=4, lev=substr(names(tm4),1,1))
+str(te4)
+te4[,,1]           # the counts part only
+
 ## ----readCsvBatch, echo=TRUE--------------------------------------------------
 path1 <- system.file("extdata", package="wrMisc")
 fiNa <-  c("pl01_1.csv","pl01_2.csv","pl02_1.csv","pl02_2.csv")
@@ -565,25 +711,37 @@ str(datAll)
 ## An example url with tabulated data :
 url1 <- "https://github.com/bigbio/proteomics-metadata-standard/blob/master/annotated-projects/PXD001819/PXD001819.sdrf.tsv"
 gitDataUrl(url1)
-dataPxd <- read.delim(gitDataUrl(url1), sep='\t', header=TRUE)
+
+## ----readGit2, echo=TRUE------------------------------------------------------
+dataPxd <- try(read.delim(gitDataUrl(url1), sep='\t', header=TRUE))
 str(dataPxd)
 
-## ----presenceFilt, echo=TRUE--------------------------------------------------
+## ----presenceGrpFilt1, echo=TRUE----------------------------------------------
 dat1 <- matrix(1:56,ncol=7)
 dat1[c(2,3,4,5,6,10,12,18,19,20,22,23,26,27,28,30,31,34,38,39,50,54)] <- NA
-dat1; presenceFilt(dat1, gr=gl(3,3)[-(3:4)], maxGr=0)
-presenceFilt(dat1, gr=gl(2,4)[-1], maxGr=1, ratM=0.1)
-presenceFilt(dat1, gr=gl(2,4)[-1], maxGr=2, rat=0.5)
+grp1 <- gl(3,3)[-(3:4)]
+dat1
+
+## now let's filter
+presenceGrpFilt(dat1, gr=grp1, presThr=0.75)  # stringent
+presenceGrpFilt(dat1, gr=grp1, presThr=0.25)  # less stringent
+
+
+## ----presenceFilt, echo=TRUE--------------------------------------------------
+presenceFilt(dat1, gr=grp1, maxGr=1, ratM=0.1)
+presenceFilt(dat1, gr=grp1, maxGr=2, rat=0.5)
 
 ## ----cleanReplicates, echo=TRUE-----------------------------------------------
 
-mat3 <- matrix(c(19,20,30, 18,19,28, 16,14,35),ncol=3)
-cleanReplicates(mat3,nOutl=1)
+(mat3 <- matrix(c(19,20,30,40, 18,19,28,39, 16,14,35,41, 17,20,30,40), ncol=4))
+cleanReplicates(mat3, nOutl=1)
+cleanReplicates(mat3, nOutl=3)
+
 
 ## ----normalizeThis0, echo=TRUE------------------------------------------------
 set.seed(2015); rand1 <- round(runif(300) +rnorm(300,0,2),3)
 dat1 <- cbind(ser1=round(100:1 +rand1[1:100]), ser2=round(1.2*(100:1 +rand1[101:200]) -2),
-  ser3=round((100:1+rand1[201:300])^1.2-3))
+  ser3=round((100:1 +rand1[201:300])^1.2-3))
 dat1 <- cbind(dat1, ser4=round(dat1[,1]^seq(2,5,length.out=100) +rand1[11:110],1))
 ## Let's introduce some NAs
 dat1[dat1 <1] <- NA
@@ -602,14 +760,30 @@ no4 <- normalizeThis(dat1, refGrp=1:3, meth="slope", quantFa=c(0.2,0.8))
 boxplot(dat1, main="raw data", las=1)
 
 ## ----normalizeThis_plot2, echo=FALSE,eval=TRUE--------------------------------
-layout(matrix(1:4,ncol=2))
+layout(matrix(1:4, ncol=2))
 boxplot(no1, main="mean normalization", las=1)
 boxplot(no2, main="trimMean normalization", las=1)
 boxplot(no3, main="median normalization", las=1)
 boxplot(no4, main="slope normalization", las=1)
 
-## ----coordOfFilt1, echo=FALSE,eval=TRUE---------------------------------------
-set.seed(2021); ma1 <- matrix(sample.int(n=40,size=27,replace=TRUE), ncol=9)
+## ----rowNormalize1, echo=TRUE-------------------------------------------------
+set.seed(2); AA <- matrix(rbinom(110, 10, 0.05), nrow=10)
+AA[,4:5] <- AA[,4:5] *rep(4:3, each=nrow(AA))
+
+AA1 <- rowNormalize(AA)
+round(AA1, 2)
+
+## ----rowNormalize2, echo=TRUE-------------------------------------------------
+AC <- AA
+AC[which(AC <1)] <- NA
+
+(AC1 <- rowNormalize(AC))
+
+## ----rowNormalize3, echo=TRUE-------------------------------------------------
+(AC3 <- rowNormalize(AC, refLines=1:5, omitNonAlignable=TRUE))
+
+## ----coordOfFilt1, echo=TRUE--------------------------------------------------
+set.seed(2021); ma1 <- matrix(sample.int(n=40, size=27, replace=TRUE), ncol=9)
 ## let's test which values are >37
 which(ma1 >37)      # doesn't tell which row & col
 coordOfFilt(ma1, ma1 >37)
@@ -649,7 +823,7 @@ if("list" %in% mode(fit4)) {  # if you have limma installed we can look further
 ## ----moderTestXgrp, echo=TRUE-------------------------------------------------
 grp <- factor(rep(LETTERS[c(3,1,4)], c(2,3,3)))
 set.seed(2017); t8 <- matrix(round(rnorm(208*8,10,0.4),2), ncol=8,
-  dimnames=list(paste(letters[],rep(1:8,each=26),sep=""), paste(grp,c(1:2,1:3,1:3),sep="")))
+  dimnames=list(paste(letters[], rep(1:8,each=26),sep=""), paste(grp,c(1:2,1:3,1:3),sep="")))
 t8[3:6,1:2] <- t8[3:6,1:2] +3                    # augment lines 3:6 (c-f) 
 t8[5:8,c(1:2,6:8)] <- t8[5:8,c(1:2,6:8)] -1.5    # lower lines 
 t8[6:7,3:5] <- t8[6:7,3:5] +2.2                  # augment lines 
@@ -666,15 +840,38 @@ t8[3:6,1:2] <- t8[3:6,1:2] +3   # augment lines 3:6 (c-f) for AA1&BB1
 t8[5:8,5:6] <- t8[5:8,5:6] +3   # augment lines 5:8 (e-h) for AA2&BB2 (c,d,g,h should be found)
 head(pVal2lfdr(apply(t8, 1, function(x) t.test(x[1:4], x[5:8])$p.value)))
 
+## ----fcCI, echo=TRUE----------------------------------------------------------
+set.seed(2022); ran <- rnorm(50)
+confInt(ran, alpha=0.05)
+## plot points and confindence interval of mean
+plot(ran, jitter(rep(1, length(ran))), ylim=c(0.95, 1.05), xlab="random variable 'ran'",main="Points and Confidence Interval of Mean (alpha=0.05)", ylab="", las=1)
+points(mean(ran), 0.97, pch=3, col=4)     # mean
+lines(mean(ran) +c(-1, 1) *confInt(ran, 0.05), c(0.97, 0.97), lwd=4, col=4)  # CI
+legend("topleft","95% conficence interval of mean", text.col=4,col=4,lty=1,lwd=1,seg.len=1.2,cex=0.9,xjust=0,yjust=0.5)
+
 ## ----matchSampToPairw, echo=TRUE----------------------------------------------
 ## make example if limma is not installed
-if(!requireNamespace("limma", quietly=TRUE)) test8 <- list(FDR=matrix(1,nrow=2,ncol=3,dimnames=list(NULL,c("A-C","A-D","C-D")))) 
+if(!requireNamespace("limma", quietly=TRUE)) test8 <- list(FDR=matrix(1, nrow=2, ncol=3, dimnames=list(NULL,c("A-C","A-D","C-D"))))
 matchSampToPairw(unique(grp), colnames(test8$FDR)) 
 
 ## ----pairWiseConc1, echo=TRUE-------------------------------------------------
 mat1 <- matrix(1:8, nrow=2, dimnames=list(NULL, paste0(1:4,"-",6:9)))
 numPairDeColNames(mat1)
 
+## ----replicateStructure1, echo=TRUE-------------------------------------------
+## column a is all different, b is groups of 2,
+## c & d  are groups of 2 nut NOT 'same general' pattern as b
+strX <- data.frame(a=letters[18:11], b=letters[rep(c(3:1,4), each=2)],
+ c=letters[rep(c(5,8:6), each=2)], d=letters[c(1:2,1:3,3:4,4)],
+ e=letters[rep(c(4,8,4,7),each=2)], f=rep("z",8) )
+strX
+
+replicateStructure(strX[,1:2])
+replicateStructure(strX[,1:4], method="combAll")
+replicateStructure(strX[,1:4], method="combAll", exclNoRepl=FALSE)
+replicateStructure(strX[,1:4], method="combNonOrth", exclNoRepl=TRUE)
+replicateStructure(strX, method="lowest")
+
 ## ----std1, echo=TRUE----------------------------------------------------------
 dat <- matrix(2*round(runif(100),2), ncol=4)
 mean(dat); sd(dat)
@@ -770,7 +967,7 @@ plot(1:15, dat1, pch=16, cex=2, las=1, col=colorAccording2(dat1),
   main="Color gradient according to value in y")
 # Here we modify the span of the color gradient
 plot(1:15, dat1, pch=16, cex=2, las=1, 
-  col=colorAccording2(dat1,nStartO=0,nEndO=4,revCol=TRUE), main="blue to red")
+  col=colorAccording2(dat1, nStartO=0, nEndO=4, revCol=TRUE), main="blue to red")
 # It is also possible to work with scales of transparency
 plot(1:9, pch=3, las=1)
 points(1:9, 1:9, col=transpGraySca(st=0, en=0.8, nSt=9,trans=0.3), cex=42, pch=16)
